@@ -247,7 +247,7 @@ class InAgentClient(BaseInAgentClient):
     async def send_payment(self, order_db: models.Order, dest):
         if order_db.status not in (OrderStatus.created, OrderStatus.requested):
             return
-        int_am = int(float(order_db.amount))
+        int_am = round(order_db.amount * 10**-2, 2)
         pma, cur = await self.get_pma_by_pmex(order_db)
         async with in_transaction():
             # отмечаем ордер на бирже "оплачен"
@@ -298,7 +298,8 @@ class InAgentClient(BaseInAgentClient):
         ).prefetch_related("cred__pmcur__cur")
         pmas = [pma for cdx in cdxs if (pma := self.pmacs.get(cdx.cred.pmcur.pm_id))]
         if not len(pmas):
-            raise Exception(order.paymentTermList, f"No pm_agents for {order.paymentTermList[0].paymentType}")
+            # raise ValueError(order.paymentTermList, f"No pm_agents for {order.paymentTermList[0].paymentType}")
+            return None
         elif len(pmas) > 1:
             logging.error(order.paymentTermList, f">1 pm_agents for {cdxs[0].cred.pmcur.pm_id}")
         else:
@@ -325,7 +326,7 @@ async def main():
 
     actor = (
         await models.Actor.filter(
-            ex_id=9,
+            ex_id=4,
             agent__auth__isnull=False,
             person__user__status=UserStatus.ACTIVE,
             person__user__pm_agents__isnull=False,
