@@ -1,3 +1,5 @@
+from time import sleep
+
 from selenium.webdriver.common.by import By
 import undetected_chromedriver as uc
 from xync_schema.models import PmAgent
@@ -22,6 +24,7 @@ async def login(agent: PmAgent):
         password_field = wait.until(EC.presence_of_element_located((By.NAME, "password")))
         password_field.send_keys(agent.auth.get("password"))
         login_button = wait.until(EC.element_to_be_clickable((By.CLASS_NAME, "login-form__login-btn.step1")))
+        sleep(1)
         try:
             login_button.click()
         except Exception:
@@ -42,6 +45,7 @@ async def login(agent: PmAgent):
             except Exception:
                 driver.execute_script("arguments[0].click();", step2_button)
 
+        sleep(1)
         agent.state = {"cookies": driver.get_cookies()}
         await agent.save()
     finally:
